(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     74439,       1910]
NotebookOptionsPosition[     71158,       1800]
NotebookOutlinePosition[     71513,       1816]
CellTagsIndexPosition[     71470,       1813]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Quantifying the Potential of Ultra-permeable Membranes for Water Desalination\
\
\>", "Title",
 CellChangeTimes->{{3.566908964376309*^9, 3.5669089709904137`*^9}, 
   3.594052151026176*^9}],

Cell["All Rights Reserved, David Cohen-Tanugi", "Subtitle",
 CellChangeTimes->{{3.566908974349779*^9, 3.566908982566264*^9}, {
   3.567874258449093*^9, 3.5678742646888933`*^9}, {3.568028520326201*^9, 
   3.568028520470199*^9}, {3.568390028179494*^9, 3.56839002867297*^9}, {
   3.568542906509686*^9, 3.5685429068531513`*^9}, {3.574964661563031*^9, 
   3.574964663487859*^9}, {3.575240455120903*^9, 3.575240456206049*^9}, {
   3.575910760776846*^9, 3.575910761065988*^9}, 3.575910812746991*^9, {
   3.586000956118504*^9, 3.586000958104829*^9}, {3.593185104863902*^9, 
   3.5931851077574587`*^9}, {3.594052113571974*^9, 3.594052131594448*^9}, 
   3.594474465812085*^9}],

Cell[CellGroupData[{

Cell["Initialization:", "Subsubsection",
 CellChangeTimes->{{3.5749646480684433`*^9, 3.574964652565311*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "AllQuantities", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Plot", ",", "LogLinearPlot", ",", "ListPlot"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"BaseStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "Helvetica"}], ",", 
         RowBox[{"FontSize", "\[Rule]", "12"}]}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", "Thick"}]}], "}"}], ",", 
    RowBox[{"Filling", "\[Rule]", "None"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "Automatic"}], "}"}]}], ",", 
    RowBox[{"Frame", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"True", ",", "True", ",", "False", ",", "False"}], "}"}]}]}], 
   "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"Plot", ",", "LogLinearPlot"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PlotPoints", "\[Rule]", "16"}], ",", 
      RowBox[{"MaxRecursion", "\[Rule]", "2"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ToSI", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"QuantityMagnitude", "[", 
     RowBox[{"UnitConvert", "[", "x", "]"}], "]"}], "//", "N"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"myLabel", "[", 
    RowBox[{"{", 
     RowBox[{"str_", ",", " ", 
      RowBox[{"{", 
       RowBox[{"x1_", ",", " ", "y1_"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"xo_", ",", " ", "yo_"}], "}"}]}], "}"}], "]"}], " ", ":=", 
   " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x2", ",", " ", "y2"}], "}"}], ",", " ", 
     RowBox[{
      RowBox[{"x2", " ", "=", " ", 
       RowBox[{"x1", " ", "+", " ", "xo"}]}], ";", " ", 
      RowBox[{"y2", " ", "=", " ", 
       RowBox[{"y1", " ", "+", " ", "yo"}]}], ";", "\n", "   ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Inset", "[", 
         RowBox[{
          RowBox[{"Style", "[", "str", "]"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"x2", ",", " ", "y2"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"1.2", " ", 
             RowBox[{"Sign", "[", 
              RowBox[{"x1", " ", "-", " ", "x2"}], "]"}]}], ",", " ", 
            RowBox[{
             RowBox[{"Sign", "[", 
              RowBox[{"y1", " ", "-", " ", "y2"}], "]"}], " ", 
             RowBox[{"Boole", "[", 
              RowBox[{"x1", " ", "==", " ", "x2"}], "]"}]}]}], "}"}]}], "]"}],
         ",", " ", "Thick", ",", " ", 
        RowBox[{"BezierCurve", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"0.9", " ", "x1"}], " ", "+", " ", 
              RowBox[{"0.1", " ", "x2"}]}], ",", " ", 
             RowBox[{
              RowBox[{"0.9", " ", "y1"}], " ", "+", " ", 
              RowBox[{"0.1", " ", "y2"}]}]}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"x1", ",", " ", "y2"}], "}"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"x2", ",", " ", "y2"}], "}"}]}], "}"}], "]"}]}], 
       "}"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lmhbar", "=", 
   RowBox[{
    RowBox[{"Quantity", "[", 
     RowBox[{"1", ",", "\"\<L/m2/hr/bar\>\""}], "]"}], "//", "ToSI"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PaTokwHm3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"UnitConvert", "[", 
      RowBox[{
       RowBox[{"Quantity", "[", 
        RowBox[{"1", ",", "\"\<Pa\>\""}], "]"}], ",", 
       "\"\<kilowatthour/m3\>\""}], "]"}], "//", "N"}], "//", 
    "QuantityMagnitude"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5666514090296707`*^9, 3.5666514127703238`*^9}, {
   3.566750073533119*^9, 3.566750089709654*^9}, {3.5667501218893747`*^9, 
   3.566750123372304*^9}, 3.566750415489579*^9, {3.566832443442021*^9, 
   3.566832458384987*^9}, {3.566908002025978*^9, 3.566908002117509*^9}, {
   3.566908202114006*^9, 3.566908204094582*^9}, {3.567957438997299*^9, 
   3.567957444487851*^9}, {3.568029158314096*^9, 3.568029163266809*^9}, {
   3.569953854245845*^9, 3.569953863127108*^9}, {3.56995389528657*^9, 
   3.569953907754533*^9}, {3.572693039882374*^9, 3.572693044200255*^9}, {
   3.5749645820684347`*^9, 3.574964583961347*^9}, 3.5750415429529037`*^9, {
   3.575044843300603*^9, 3.5750448748545227`*^9}, {3.57504490677704*^9, 
   3.5750449309389477`*^9}, {3.5750456177258587`*^9, 3.575045636841125*^9}, 
   3.5750456765983753`*^9, {3.575050184199704*^9, 3.5750502245040417`*^9}, {
   3.575050312812674*^9, 3.5750503252837887`*^9}, {3.575050398443083*^9, 
   3.575050429999997*^9}, {3.575060179044292*^9, 3.5750602136393633`*^9}, {
   3.575067482369109*^9, 3.575067483903789*^9}, {3.5751260176817827`*^9, 
   3.5751260465958433`*^9}, {3.588414889573843*^9, 3.588414892218914*^9}, 
   3.593185426649757*^9, 3.5931854965688667`*^9, {3.593186643271315*^9, 
   3.593186644865512*^9}, {3.5931877633526297`*^9, 3.593187853091776*^9}, {
   3.593187906631495*^9, 3.593187957332995*^9}, {3.593364992739378*^9, 
   3.5933650007972517`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definitions", "Section",
 CellChangeTimes->{{3.5666495238342113`*^9, 3.566649528237279*^9}, {
  3.566656345870552*^9, 3.566656349904787*^9}, {3.5749666593933697`*^9, 
  3.57496666109239*^9}, {3.594052078660369*^9, 3.594052080331634*^9}}],

Cell[CellGroupData[{

Cell["Definitions", "Subsection",
 CellChangeTimes->{{3.5745985184912663`*^9, 3.574598519377802*^9}, {
  3.574966744579136*^9, 3.57496674780028*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"J", "[", 
     RowBox[{"P_", ",", "Q_", ",", "cb_", ",", "Lp_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"Lp", " ", "P"}], "-", 
     RowBox[{
      RowBox[{"k", "[", 
       RowBox[{"P", ",", "Q", ",", "Lp"}], "]"}], " ", 
      RowBox[{"ProductLog", "[", 
       FractionBox[
        RowBox[{"2", " ", "cb", " ", 
         SuperscriptBox["\[ExponentialE]", 
          FractionBox[
           RowBox[{"Lp", " ", "P"}], 
           RowBox[{"k", "[", 
            RowBox[{"P", ",", "Q", ",", "Lp"}], "]"}]]], " ", "Lp", " ", "R", 
         " ", "R0", " ", "T"}], 
        RowBox[{"k", "[", 
         RowBox[{"P", ",", "Q", ",", "Lp"}], "]"}]], "]"}]}]}]}], ";"}], " ", 
  
  RowBox[{"(*", " ", 
   RowBox[{"Permeate", " ", "flux"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"k", "[", 
     RowBox[{"P_", ",", "Q_", ",", "Lp_"}], "]"}], ":=", 
    FractionBox[
     RowBox[{"2.53", " ", "\[ScriptCapitalD]", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{"16.", " ", 
           SuperscriptBox["Q", "2"], " ", 
           SuperscriptBox["\[Rho]", "2"]}], 
          RowBox[{
           SuperscriptBox["Wc", "2"], " ", 
           SuperscriptBox["\[Mu]", "2"]}]], "+", 
         RowBox[{"0.4892", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox[
             RowBox[{"Q", " ", "\[Rho]"}], 
             RowBox[{"Wc", " ", "\[Mu]"}]], ")"}], "2.964"]}]}], ")"}], 
       "0.2362"]}], "Hc"]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"mass", " ", "xfer", " ", "coefficient"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DPLost", "[", "Q_", "]"}], ":=", 
    FractionBox[
     RowBox[{"2", " ", "Wc", " ", 
      SuperscriptBox["\[Mu]", "3"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"16", " ", 
          SuperscriptBox["Q", "2"], " ", 
          SuperscriptBox["\[Rho]", "2"]}], 
         RowBox[{
          SuperscriptBox["Wc", "2"], " ", 
          SuperscriptBox["\[Mu]", "2"]}]], "+", 
        RowBox[{"0.489", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"Q", " ", "\[Rho]"}], 
            RowBox[{"Wc", " ", "\[Mu]"}]], ")"}], "2.964"]}]}], ")"}]}], 
     RowBox[{
      SuperscriptBox["Hc", "3"], " ", "Q", " ", 
      SuperscriptBox["\[Rho]", "2"]}]]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Viscous", " ", "pressure", " ", "loss", " ", "per", " ", "unit", " ", 
     "length"}], ",", " ", 
    RowBox[{"in", " ", 
     RowBox[{"Pa", "/", "m"}]}]}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.57459857612179*^9, 3.5745985764139223`*^9}, {
   3.574599602722129*^9, 3.5745996089438267`*^9}, {3.5746144725149918`*^9, 
   3.5746144733357687`*^9}, {3.574614874244235*^9, 3.5746149116307983`*^9}, {
   3.574775358992791*^9, 3.574775370139751*^9}, {3.574775549398169*^9, 
   3.574775564163333*^9}, 3.574966707618092*^9, {3.5750620855672293`*^9, 
   3.575062085902719*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "More ",
 StyleBox["definitions",
  FontWeight->"Bold"],
 ":"
}], "Subsection",
 CellChangeTimes->{{3.574787726332038*^9, 3.574787727554851*^9}, 
   3.574966764232164*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Rmax", "[", 
     RowBox[{"P_", ",", "c0_"}], "]"}], ":=", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", " ", "R", " ", "T", " ", "c0"}], "P"]}], ")"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
   "Max", " ", "recovery", " ", "achievable", " ", "given", " ", "the", " ", 
    "inlet", " ", "pressure", " ", "and", " ", "the", " ", "feed", " ", 
    "salinity"}], " ", "*)"}], " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Pmin", "[", 
    RowBox[{"c0_", ",", "recovery_"}], "]"}], ":=", 
   RowBox[{"2", "R", " ", "T", " ", 
    RowBox[{"(", 
     FractionBox["c0", 
      RowBox[{"1", "-", "recovery"}]], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"OsmoticPressure", "[", 
    RowBox[{"P_", ",", "Q_", ",", "cb_", ",", "Lp_"}], "]"}], ":=", 
   RowBox[{"2", " ", "cb", " ", 
    SuperscriptBox["\[ExponentialE]", 
     FractionBox[
      RowBox[{"J", "[", 
       RowBox[{"P", ",", "Q", ",", "cb", ",", "Lp"}], "]"}], 
      RowBox[{"k", "[", 
       RowBox[{"P", ",", "Q", ",", "Lp"}], "]"}]]], "  ", "R", " ", "R0", " ",
     "T"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cm", "[", 
     RowBox[{"P_", ",", "Q_", ",", "cb_", ",", "Lp_"}], "]"}], ":=", 
    RowBox[{"cb", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "R0"}], ")"}], "+", 
       RowBox[{"R0", " ", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"J", "[", 
           RowBox[{"P", ",", "Q", ",", "cb", ",", "Lp"}], "]"}], 
          RowBox[{"k", "[", 
           RowBox[{"P", ",", "Q", ",", "Lp"}], "]"}]]]}]}], "  ", ")"}]}]}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Concentration", " ", "polarization", " ", "factor"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CPF", "[", 
    RowBox[{"P_", ",", "Q_", ",", "cb_", ",", "Lp_"}], "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", "R0"}], ")"}], "+", 
     RowBox[{"R0", " ", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"J", "[", 
         RowBox[{"P", ",", "Q", ",", "cb", ",", "Lp"}], "]"}], 
        RowBox[{"k", "[", 
         RowBox[{"P", ",", "Q", ",", "Lp"}], "]"}]]]}]}], "  ", ")"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.574787734571527*^9, 3.574787735047847*^9}, {
  3.575065823077116*^9, 3.575065852223504*^9}, {3.575105537657316*^9, 
  3.5751055810416813`*^9}, {3.575105795133651*^9, 3.57510579552071*^9}, {
  3.575106353599183*^9, 3.5751063779659357`*^9}, {3.575106493205696*^9, 
  3.575106498468833*^9}, {3.575106568322281*^9, 3.575106587522448*^9}, {
  3.5751067651471157`*^9, 3.575106772127775*^9}, {3.575910862353959*^9, 
  3.575910863798918*^9}, {3.5759109636825323`*^9, 3.575910975968532*^9}, {
  3.5759112393140583`*^9, 3.5759113615741158`*^9}, {3.594051869653256*^9, 
  3.594051870041013*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Energy consumption", "Subsection",
 CellChangeTimes->{{3.5931861605379353`*^9, 3.593186166403934*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"energycons3", "[", 
    RowBox[{
     RowBox[{"Q0_", "?", "NumberQ"}], ",", 
     RowBox[{"recov_", "?", "NumberQ"}], ",", 
     RowBox[{"c0_", "?", "NumberQ"}], ",", 
     RowBox[{"Lp_", "?", "NumberQ"}], ",", 
     RowBox[{"Lc_", "?", "NumberQ"}], ",", 
     RowBox[{"\[Xi]_", "?", "NumberQ"}]}], "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"thisP", "=", 
      RowBox[{"ToSI", "[", 
       RowBox[{"RequiredP", "[", 
        RowBox[{"Q0", ",", "recov", ",", "c0", ",", "Lp", ",", "Lc"}], "]"}], 
       "]"}]}], ";", 
     RowBox[{
      FractionBox["1", "3600000"], 
      FractionBox["1", "\[Eta]"], 
      FractionBox["1", "recov"], 
      RowBox[{"(", 
       RowBox[{"thisP", "-", 
        RowBox[{"\[Xi]", 
         RowBox[{"(", 
          RowBox[{"1", "-", "recov"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"thisP", "-", 
           RowBox[{"PLost", "[", 
            RowBox[{"thisP", ",", "Q0", ",", "c0", ",", "Lp", ",", "Lc"}], 
            "]"}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ";"}]], "Input",
 CellChangeTimes->{3.5931861724452143`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Governing ",
 StyleBox["differential equations:",
  FontWeight->"Bold"]
}], "Subsection",
 CellChangeTimes->{{3.574598524539805*^9, 3.5745985259112577`*^9}, {
  3.5749667529465923`*^9, 3.574966762706501*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PressureEquation", "[", 
    RowBox[{"Q0_", ",", "P0_"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"P", "'"}], "[", "z", "]"}], "==", 
      RowBox[{"-", 
       RowBox[{"DPLost", "[", 
        RowBox[{"Q", "[", "z", "]"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"P", "[", "0", "]"}], "\[Equal]", "P0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FlowrateEquation", "[", "Q0_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Q", "[", "z", "]"}], "\[Equal]", 
     RowBox[{"Q0", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"\[CapitalPhi]", "[", "z", "]"}]}], ")"}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RecoveryEquation", "[", 
    RowBox[{"Q0_", ",", "Lp_"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalPhi]", "'"}], "[", "z", "]"}], "==", 
      RowBox[{
       FractionBox["Wc", "Q0"], 
       RowBox[{"J", "[", 
        RowBox[{
         RowBox[{"P", "[", "z", "]"}], ",", 
         RowBox[{"Q", "[", "z", "]"}], ",", 
         RowBox[{"cb", "[", "z", "]"}], ",", "Lp"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"\[CapitalPhi]", "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SalinityEquation", "[", "c0_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"cb", "[", "z", "]"}], "\[Equal]", 
      FractionBox["c0", 
       RowBox[{"1", "-", 
        RowBox[{"\[CapitalPhi]", "[", "z", "]"}]}]]}], ",", 
     RowBox[{
      RowBox[{"cb", "[", "0", "]"}], "\[Equal]", "c0"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.574594948437037*^9, 3.574595075957219*^9}, {
   3.5745951570338507`*^9, 3.574595159225464*^9}, {3.574595238457386*^9, 
   3.574595287901061*^9}, {3.5745971947669687`*^9, 3.574597340424571*^9}, {
   3.57459839401197*^9, 3.574598422055667*^9}, {3.574598466889044*^9, 
   3.574598497239992*^9}, {3.574598531114587*^9, 3.5745985432611094`*^9}, {
   3.574598582549429*^9, 3.574598587499146*^9}, {3.5745987111239443`*^9, 
   3.5745987112153063`*^9}, {3.574598912544842*^9, 3.57459891300568*^9}, {
   3.574599636197769*^9, 3.574599637800992*^9}, {3.5746001059655457`*^9, 
   3.574600106123651*^9}, {3.574610238641927*^9, 3.574610310305591*^9}, {
   3.57461037769683*^9, 3.57461038870814*^9}, 3.5746104251427107`*^9, {
   3.574614496501458*^9, 3.574614500307703*^9}, {3.574614577742478*^9, 
   3.5746145790508013`*^9}, {3.574614679095745*^9, 3.574614694181203*^9}, 
   3.574775412320024*^9, {3.5747755528640423`*^9, 3.5747755585847807`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Defining ",
 StyleBox["recovery",
  FontWeight->"Bold"],
 " as a function of inlet parameters:"
}], "Subsection",
 CellChangeTimes->{{3.574966781025317*^9, 3.5749667952936707`*^9}, 
   3.574966927924982*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Permeate", " ", "recovery", " ", "as", " ", "a", " ", "function", " ", 
     "of", " ", "inlet", " ", "values", " ", "for", " ", "pressure"}], ",", 
    " ", 
    RowBox[{"feed", " ", "flowrate"}], ",", " ", "salinity", ",", " ", 
    RowBox[{
    "as", " ", "well", " ", "as", " ", "RO", " ", "vessel", " ", "length", 
     " ", "and", " ", "membrane", " ", "permeability"}]}], " ", "*)"}], " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Recovery", "[", 
      RowBox[{
       RowBox[{"P0_", "?", "NumberQ"}], ",", 
       RowBox[{"Q0_", "?", "NumberQ"}], ",", 
       RowBox[{"c0_", "?", "NumberQ"}], ",", 
       RowBox[{"Lp_", "?", "NumberQ"}], ",", 
       RowBox[{"Lc_", "?", "NumberQ"}]}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalPhi]", "[", "Lc", "]"}], "/.", 
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"P", "'"}], "[", "z", "]"}], "==", 
            RowBox[{"-", 
             RowBox[{"DPLost", "[", 
              RowBox[{"Q", "[", "z", "]"}], "]"}]}]}], ",", 
           RowBox[{
            RowBox[{"P", "[", "0", "]"}], "\[Equal]", "P0"}], ",", 
           RowBox[{
            RowBox[{"Q", "[", "z", "]"}], "\[Equal]", 
            RowBox[{"Q0", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"\[CapitalPhi]", "[", "z", "]"}]}], ")"}]}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"\[CapitalPhi]", "'"}], "[", "z", "]"}], "==", 
            RowBox[{
             FractionBox["Wc", "Q0"], 
             RowBox[{"J", "[", 
              RowBox[{
               RowBox[{"P", "[", "z", "]"}], ",", 
               RowBox[{"Q", "[", "z", "]"}], ",", 
               RowBox[{"cb", "[", "z", "]"}], ",", "Lp"}], "]"}]}]}], ",", 
           RowBox[{
            RowBox[{"\[CapitalPhi]", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
           
           RowBox[{
            RowBox[{"cb", "[", "z", "]"}], "\[Equal]", 
            FractionBox["c0", 
             RowBox[{"1", "-", 
              RowBox[{"\[CapitalPhi]", "[", "z", "]"}]}]]}], ",", 
           RowBox[{
            RowBox[{"cb", "[", "0", "]"}], "\[Equal]", "c0"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"P", ",", "Q", ",", "\[CapitalPhi]", ",", "cb"}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "0", ",", "Lc"}], "}"}]}], "]"}]}], "//", 
      "First"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Pressure", " ", "lost", " ", "over", " ", "entire", " ", "RO", " ", 
     "vessel"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PLost", "[", 
      RowBox[{
       RowBox[{"P0_", "?", "NumberQ"}], ",", 
       RowBox[{"Q0_", "?", "NumberQ"}], ",", 
       RowBox[{"c0_", "?", "NumberQ"}], ",", 
       RowBox[{"Lp_", "?", "NumberQ"}], ",", 
       RowBox[{"Lc_", "?", "NumberQ"}]}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"P0", "-", 
         RowBox[{"P", "[", "Lc", "]"}]}], ")"}], "/.", 
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"P", "'"}], "[", "z", "]"}], "==", 
            RowBox[{"-", 
             RowBox[{"DPLost", "[", 
              RowBox[{"Q", "[", "z", "]"}], "]"}]}]}], ",", 
           RowBox[{
            RowBox[{"P", "[", "0", "]"}], "\[Equal]", "P0"}], ",", 
           RowBox[{
            RowBox[{"Q", "[", "z", "]"}], "\[Equal]", 
            RowBox[{"Q0", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"\[CapitalPhi]", "[", "z", "]"}]}], ")"}]}]}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"\[CapitalPhi]", "'"}], "[", "z", "]"}], "==", 
            RowBox[{
             FractionBox["Wc", "Q0"], 
             RowBox[{"J", "[", 
              RowBox[{
               RowBox[{"P", "[", "z", "]"}], ",", 
               RowBox[{"Q", "[", "z", "]"}], ",", 
               RowBox[{"cb", "[", "z", "]"}], ",", "Lp"}], "]"}]}]}], ",", 
           RowBox[{
            RowBox[{"\[CapitalPhi]", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
           
           RowBox[{
            RowBox[{"cb", "[", "z", "]"}], "\[Equal]", 
            FractionBox["c0", 
             RowBox[{"1", "-", 
              RowBox[{"\[CapitalPhi]", "[", "z", "]"}]}]]}], ",", 
           RowBox[{
            RowBox[{"cb", "[", "0", "]"}], "\[Equal]", "c0"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"P", ",", "Q", ",", "\[CapitalPhi]", ",", "cb"}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", "0", ",", "Lc"}], "}"}]}], "]"}]}], "//", 
      "First"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   StyleBox[" ", "Code"], 
   RowBox[{
    StyleBox["(*", "Code"], " ", 
    RowBox[{
     RowBox[{"Flow", " ", "profile"}], ",", " ", 
     RowBox[{"returns", " ", "four", " ", "functions", " ", "P", 
      RowBox[{"(", "z", ")"}]}], ",", " ", 
     RowBox[{"Q", 
      RowBox[{"(", "z", ")"}]}], ",", " ", 
     RowBox[{"\[CapitalPhi]", 
      RowBox[{"(", "z", ")"}], " ", "and", " ", "cb", 
      RowBox[{
       RowBox[{"(", "z", ")"}], ".", " ", "Useful"}], " ", "for", " ", 
      "plotting"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Profile", "[", 
      RowBox[{
       RowBox[{"P0_", "?", "NumberQ"}], ",", 
       RowBox[{"Q0_", "?", "NumberQ"}], ",", 
       RowBox[{"c0_", "?", "NumberQ"}], ",", 
       RowBox[{"Lp_", "?", "NumberQ"}], ",", 
       RowBox[{"Lc_", "?", "NumberQ"}]}], "]"}], ":=", 
     RowBox[{"NDSolve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"P", "'"}], "[", "z", "]"}], "==", 
          RowBox[{"-", 
           RowBox[{"DPLost", "[", 
            RowBox[{"Q", "[", "z", "]"}], "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"P", "[", "0", "]"}], "\[Equal]", "P0"}], ",", 
         RowBox[{
          RowBox[{"Q", "[", "z", "]"}], "\[Equal]", 
          RowBox[{"Q0", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"\[CapitalPhi]", "[", "z", "]"}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"\[CapitalPhi]", "'"}], "[", "z", "]"}], "==", 
          RowBox[{
           FractionBox["Wc", "Q0"], 
           RowBox[{"J", "[", 
            RowBox[{
             RowBox[{"P", "[", "z", "]"}], ",", 
             RowBox[{"Q", "[", "z", "]"}], ",", 
             RowBox[{"cb", "[", "z", "]"}], ",", "Lp"}], "]"}]}]}], ",", 
         RowBox[{
          RowBox[{"\[CapitalPhi]", "[", "0", "]"}], "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"cb", "[", "z", "]"}], "\[Equal]", 
          FractionBox["c0", 
           RowBox[{"1", "-", 
            RowBox[{"\[CapitalPhi]", "[", "z", "]"}]}]]}], ",", 
         RowBox[{
          RowBox[{"cb", "[", "0", "]"}], "\[Equal]", "c0"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"P", ",", "Q", ",", "\[CapitalPhi]", ",", "cb"}], "}"}], ",", 
       
       RowBox[{"{", 
        RowBox[{"z", ",", "0", ",", "Lc"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Calculate", " ", "the", " ", "maximum", " ", "value", " ", "of", " ", 
     "the", " ", "Concentration", " ", "Polarization", " ", "Factor", " ", 
     RowBox[{"(", "CPF", ")"}], " ", "for", " ", "given", " ", "inlet", " ", 
     "parameters"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"CPFmax", "[", 
      RowBox[{"P0_", ",", "Q0_", ",", "c0_", ",", "Lp_", ",", "Lc_"}], "]"}], 
     ":=", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"a", "=", 
        RowBox[{"Profile", "[", 
         RowBox[{"P0", ",", "Q0", ",", "c0", ",", "Lp", ",", "Lc"}], "]"}]}], 
       ";", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "R0"}], ")"}], "+", 
           RowBox[{"R0", " ", 
            SuperscriptBox["\[ExponentialE]", 
             FractionBox[
              RowBox[{"J", "[", 
               RowBox[{
                RowBox[{"P", "[", "0", "]"}], ",", 
                RowBox[{"Q", "[", "0", "]"}], ",", 
                RowBox[{"cb", "[", "0", "]"}], ",", "Lp"}], "]"}], 
              RowBox[{"k", "[", 
               RowBox[{
                RowBox[{"P", "[", "0", "]"}], ",", 
                RowBox[{"Q", "[", "0", "]"}], ",", "Lp"}], "]"}]]]}]}], "  ", 
          ")"}], "/.", "a"}], "//", "First"}]}], ")"}]}], ";"}]}]}]], "Input",\

 CellChangeTimes->{{3.574966816967276*^9, 3.574966888420986*^9}, {
  3.575062046974739*^9, 3.575062079313673*^9}, {3.575062184829751*^9, 
  3.575062190270458*^9}, {3.575969218945047*^9, 3.575969342089849*^9}, {
  3.575969415448009*^9, 3.575969485156663*^9}, {3.575969572195331*^9, 
  3.575969582166109*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Physical constants", "Subsection",
 CellChangeTimes->{{3.5746105990915213`*^9, 3.574610604595851*^9}}],

Cell[CellGroupData[{

Cell["Constants", "Subsubsection",
 CellChangeTimes->{{3.574967006887186*^9, 3.574967021645546*^9}, {
  3.574967781858891*^9, 3.574967813484832*^9}, {3.59405185056579*^9, 
  3.594051851758053*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "Hc", ",", "Wc", ",", "R0", ",", "R", ",", "\[ScriptCapitalD]", ",", 
     "\[Rho]", ",", "\[Mu]", ",", "T", ",", "\[Eta]"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{"0.00071", ",", "41", ",", "0.998", ",", "8.3145", ",", 
     RowBox[{"1.13", "*", 
      RowBox[{"10", "^", 
       RowBox[{"-", "9"}]}]}], ",", "1000", ",", "0.00089", ",", "300", ",", 
     "0.75"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5749669643253527`*^9, 3.574966997906*^9}, {
  3.57496713791916*^9, 3.574967141980929*^9}, {3.575065795947919*^9, 
  3.575065799586418*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Default values for inlet parameters", "Subsubsection",
 CellChangeTimes->{{3.5749671451353407`*^9, 3.574967156606803*^9}, {
   3.574967808742798*^9, 3.574967808862879*^9}, 3.594051854006435*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Seawater", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"P0DefaultSW", "=", 
     RowBox[{
      RowBox[{"Quantity", "[", 
       RowBox[{"70", ",", " ", "\"\<bar\>\""}], "]"}], "//", "ToSI"}]}], ";", 
    
    RowBox[{"RRdefaultSW", "=", ".42"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Q0DefaultSW", "=", " ", 
     RowBox[{
      RowBox[{"Quantity", "[", 
       RowBox[{"300", " ", ",", "\"\<m3/day\>\""}], "]"}], "//", "ToSI"}]}], 
    ";", 
    RowBox[{"c0DefaultSW", "=", 
     RowBox[{
      RowBox[{"Quantity", "[", 
       RowBox[{
        FractionBox["42", "58.44"], ",", "\"\<mol/L\>\""}], "]"}], "//", 
      "ToSI"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LpDefaultSW", "=", 
     RowBox[{
      RowBox[{"Quantity", "[", 
       RowBox[{"1.", ",", "\"\<L/(m2 hr bar)\>\""}], "]"}], "//", "ToSI"}]}], 
    ";", " ", 
    RowBox[{"(*", " ", "Permeability", " ", "*)"}], " ", 
    RowBox[{"LcDefaultSW", "=", " ", 
     RowBox[{
      RowBox[{"Quantity", "[", 
       RowBox[{"8", ",", "\"\<m\>\""}], "]"}], "//", "ToSI"}]}], ";", 
    RowBox[{"\[Xi]SW", "=", ".97"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Brackish", " ", "water"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P0DefaultBW", "=", 
     RowBox[{
      RowBox[{"Quantity", "[", 
       RowBox[{"12", ",", " ", "\"\<bar\>\""}], "]"}], "//", "ToSI"}]}], ";", 
    
    RowBox[{"RRdefaultBW", "=", ".65"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Q0DefaultBW", "=", " ", 
     RowBox[{
      RowBox[{"Quantity", "[", 
       RowBox[{"140", " ", ",", "\"\<m3/day\>\""}], "]"}], "//", "ToSI"}]}], 
    ";", 
    RowBox[{"c0DefaultBW", "=", 
     RowBox[{
      RowBox[{"Quantity", "[", 
       RowBox[{
        FractionBox["2", "58.44"], ",", "\"\<mol/L\>\""}], "]"}], "//", 
      "ToSI"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LpDefaultBW", "=", 
     RowBox[{
      RowBox[{"Quantity", "[", 
       RowBox[{"1.5", ",", "\"\<L/(m2 hr bar)\>\""}], "]"}], "//", "ToSI"}]}],
     ";", " ", 
    RowBox[{"(*", " ", "Permeability", " ", "*)"}], " ", 
    RowBox[{"LcDefaultBW", "=", " ", 
     RowBox[{
      RowBox[{"Quantity", "[", 
       RowBox[{"7", ",", "\"\<m\>\""}], "]"}], "//", "ToSI"}]}], ";", 
    RowBox[{"\[Xi]BW", "=", "0."}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Oil", "/", "gas"}], " ", "water"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"P0DefaultOGW", "=", 
     RowBox[{
      RowBox[{"Quantity", "[", 
       RowBox[{"85", ",", " ", "\"\<bar\>\""}], "]"}], "//", "ToSI"}]}], ";", 
    
    RowBox[{"RRdefaultOGW", "=", ".15"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Q0DefaultOGW", "=", " ", 
     RowBox[{
      RowBox[{"Quantity", "[", 
       RowBox[{"190", " ", ",", "\"\<m3/day\>\""}], "]"}], "//", "ToSI"}]}], 
    ";", 
    RowBox[{"c0DefaultOGW", "=", 
     RowBox[{
      RowBox[{"Quantity", "[", 
       RowBox[{
        FractionBox["80", "58.44"], ",", "\"\<mol/L\>\""}], "]"}], "//", 
      "ToSI"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LpDefaultOGW", "=", 
     RowBox[{
      RowBox[{"Quantity", "[", 
       RowBox[{"1.", ",", "\"\<L/(m2 hr bar)\>\""}], "]"}], "//", "ToSI"}]}], 
    ";", " ", 
    RowBox[{"(*", " ", "Permeability", " ", "*)"}], " ", 
    RowBox[{"LcDefaultOGW", "=", " ", 
     RowBox[{
      RowBox[{"Quantity", "[", 
       RowBox[{"4", ",", "\"\<m\>\""}], "]"}], "//", "ToSI"}]}], ";", 
    RowBox[{"\[Xi]OGW", "=", ".97"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.5749669643253527`*^9, 3.574966997906*^9}, {
   3.57496713791916*^9, 3.574967141980929*^9}, {3.5749677039365187`*^9, 
   3.574967768432325*^9}, {3.574968331547249*^9, 3.5749683452677727`*^9}, {
   3.5750421777533827`*^9, 3.57504221850298*^9}, {3.5750422498719*^9, 
   3.5750422933253813`*^9}, {3.575042351416017*^9, 3.575042441425482*^9}, {
   3.575042473681314*^9, 3.575042500657077*^9}, {3.575044798592383*^9, 
   3.575044804619892*^9}, 3.575044967777774*^9, {3.5750450270092077`*^9, 
   3.575045034947378*^9}, {3.5750649965765257`*^9, 3.575065015198319*^9}, {
   3.575065086877666*^9, 3.575065087019281*^9}, {3.575065906217354*^9, 
   3.575065957353866*^9}, {3.575123996642057*^9, 3.575124011102577*^9}, {
   3.575125402876855*^9, 3.5751254091899557`*^9}, {3.575125461508985*^9, 
   3.5751254617372103`*^9}, {3.575125938797352*^9, 3.575125939031012*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Key plots", "Section",
 CellChangeTimes->{{3.594052068941886*^9, 3.594052069797071*^9}}],

Cell[CellGroupData[{

Cell["Higher throughput", "Subsection",
 CellChangeTimes->{{3.575045767153632*^9, 3.575045769794375*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "function", " ", "RequiredQ", " ", "returns", " ", 
    StyleBox["Q",
     FontSlant->"Italic"], " ", "in", " ", "SI", " ", "units", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"m3", "/", "s"}], ")"}], "."}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"RequiredQ", "[", 
      RowBox[{
       RowBox[{"P0_", "?", "NumberQ"}], ",", 
       RowBox[{"recov_", "?", "NumberQ"}], ",", 
       RowBox[{"c0_", "?", "NumberQ"}], ",", 
       RowBox[{"Lp_", "?", "NumberQ"}], ",", 
       RowBox[{"Lc_", "?", "NumberQ"}]}], "]"}], ":=", 
     RowBox[{
      RowBox[{"x", "/.", 
       RowBox[{"FindRoot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Recovery", "[", 
           RowBox[{"P0", ",", "x", ",", "c0", ",", "Lp", ",", "Lc"}], "]"}], 
          "-", "recov"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0.004"}], "}"}]}], "]"}]}], "//", "Quiet"}]}], 
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TargetPermeate", "=", "100000"}], ";", " ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
      "target", " ", "permeate", " ", "production", " ", "for", " ", "the", 
       " ", "total", " ", "plant"}], ",", " ", 
      RowBox[{"in", " ", 
       RowBox[{"m3", "/", "d"}], "\"\<\>"}]}], "*)"}], "\[IndentingNewLine]", 
    
    RowBox[{"Plot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"TargetPermeate", "/", 
         RowBox[{"(", 
          RowBox[{"RRdefaultSW", "*", "86400", "*", 
           RowBox[{"RequiredQ", "[", 
            RowBox[{
            "P0DefaultSW", ",", "RRdefaultSW", ",", "c0DefaultSW", ",", 
             RowBox[{"x", "*", "lmhbar"}], ",", "LcDefaultSW"}], "]"}]}], 
          ")"}]}], ",", 
        RowBox[{"TargetPermeate", "/", 
         RowBox[{"(", 
          RowBox[{"RRdefaultBW", "*", "86400", "*", 
           RowBox[{"RequiredQ", "[", 
            RowBox[{
            "P0DefaultBW", ",", "RRdefaultBW", ",", "c0DefaultBW", ",", 
             RowBox[{"x", "*", "lmhbar"}], ",", "LcDefaultBW"}], "]"}]}], 
          ")"}]}], ",", 
        RowBox[{"TargetPermeate", "/", 
         RowBox[{"(", 
          RowBox[{"RRdefaultOGW", "*", "86400", "*", 
           RowBox[{"RequiredQ", "[", 
            RowBox[{
            "P0DefaultOGW", ",", "RRdefaultOGW", ",", "c0DefaultOGW", ",", 
             RowBox[{"x", "*", "lmhbar"}], ",", "LcDefaultOGW"}], "]"}]}], 
          ")"}]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "10"}], "}"}], ",", 
      RowBox[{"FrameLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Permeability (L/(\!\(\*SuperscriptBox[\(m\), \(2\)]\) hr bar))\>\
\"", ",", "\"\<Number of pressure vessels\>\""}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Purple"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Orange"}], "]"}], ",", 
         RowBox[{"Directive", "[", 
          RowBox[{"Thick", ",", "Black"}], "]"}]}], "}"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"SwatchLegend", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Purple", ",", "Orange", ",", "Black"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Seawater\>\"", ",", "\"\<Brackish water\>\"", ",", 
       "\"\<Flowback water\>\""}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.575045784936139*^9, {3.575045827859518*^9, 3.575045835123375*^9}, {
   3.575051003996058*^9, 3.575051021563052*^9}, {3.575060620781137*^9, 
   3.5750606209222307`*^9}, {3.575064638603753*^9, 3.575064655067638*^9}, {
   3.575064764933433*^9, 3.5750647873882504`*^9}, 3.575064901078554*^9, 
   3.575064932990616*^9, {3.5759708024659758`*^9, 3.575970829706356*^9}, {
   3.5759723462659063`*^9, 3.575972346822699*^9}, {3.5931857188362293`*^9, 
   3.593185847334803*^9}, {3.593190850295491*^9, 3.593190859227769*^9}, {
   3.593249630021262*^9, 3.5932496483798933`*^9}, {3.593249680687278*^9, 
   3.5932496809325943`*^9}, {3.593249925622198*^9, 3.5932499257321444`*^9}, {
   3.594052090220173*^9, 3.59405209069981*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Lower pressure", "Subsection",
 CellChangeTimes->{{3.575045845537918*^9, 3.5750458465673437`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"RequiredP", "[", 
     RowBox[{
      RowBox[{"Q0_", "?", "NumberQ"}], ",", 
      RowBox[{"recov_", "?", "NumberQ"}], ",", 
      RowBox[{"c0_", "?", "NumberQ"}], ",", 
      RowBox[{"Lp_", "?", "NumberQ"}], ",", 
      RowBox[{"Lc_", "?", "NumberQ"}]}], "]"}], ":=", 
    RowBox[{"x", "/.", 
     RowBox[{"FindRoot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Recovery", "[", 
          RowBox[{"x", ",", "Q0", ",", "c0", ",", "Lp", ",", "Lc"}], "]"}], 
         "\[Equal]", "recov"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"1.", "*", 
          SuperscriptBox["10", "5"]}]}], "}"}]}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["10", 
       RowBox[{"-", "5"}]], "*", 
      RowBox[{"Pmin", "[", 
       RowBox[{"c0DefaultSW", ",", "RRdefaultSW"}], "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["10", 
       RowBox[{"-", "5"}]], "*", 
      RowBox[{"RequiredP", "[", 
       RowBox[{"Q0DefaultSW", ",", "RRdefaultSW", ",", "c0DefaultSW", ",", 
        RowBox[{"LpValue", "*", "lmhbar"}], ",", "LcDefaultSW"}], "]"}]}], 
     ",", 
     RowBox[{
      SuperscriptBox["10", 
       RowBox[{"-", "5"}]], "*", 
      RowBox[{"Pmin", "[", 
       RowBox[{"c0DefaultBW", ",", "RRdefaultBW"}], "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["10", 
       RowBox[{"-", "5"}]], "*", 
      RowBox[{"RequiredP", "[", 
       RowBox[{"Q0DefaultBW", ",", "RRdefaultBW", ",", "c0DefaultBW", ",", 
        RowBox[{"LpValue", "*", "lmhbar"}], ",", "LcDefaultBW"}], "]"}]}], 
     ",", 
     RowBox[{
      SuperscriptBox["10", 
       RowBox[{"-", "5"}]], "*", 
      RowBox[{"Pmin", "[", 
       RowBox[{"c0DefaultOGW", ",", "RRdefaultOGW"}], "]"}]}], ",", 
     RowBox[{
      SuperscriptBox["10", 
       RowBox[{"-", "5"}]], "*", 
      RowBox[{"RequiredP", "[", 
       RowBox[{
       "Q0DefaultOGW", ",", "RRdefaultOGW", ",", "c0DefaultOGW", ",", 
        RowBox[{"LpValue", "*", "lmhbar"}], ",", "LcDefaultOGW"}], "]"}]}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"LpValue", ",", "0.1", ",", "10"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Dotted", ",", "Thick"}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "100"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Permeability (L/(\!\(\*SuperscriptBox[\(m\), \(2\)]\) hr bar))\>\"",
       ",", "\"\<Inlet pressure (bar)\>\""}], "}"}]}], ",", 
   RowBox[{"Filling", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "\[Rule]", 
       RowBox[{"{", "2", "}"}]}], ",", 
      RowBox[{"3", "\[Rule]", 
       RowBox[{"{", "4", "}"}]}], ",", 
      RowBox[{"5", "\[Rule]", 
       RowBox[{"{", "6", "}"}]}]}], "}"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"SwatchLegend", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ColorData", "[", 
      RowBox[{"1", ",", "2"}], "]"}], ",", 
     RowBox[{"ColorData", "[", 
      RowBox[{"1", ",", "4"}], "]"}], ",", 
     RowBox[{"ColorData", "[", 
      RowBox[{"1", ",", "6"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Seawater\>\"", ",", "\"\<Brackish water\>\"", ",", 
     "\"\<Flowback water\>\""}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.575046271200459*^9, 3.57504627609406*^9}, {
   3.5750463691223707`*^9, 3.575046531965032*^9}, {3.5750466517205048`*^9, 
   3.575046733181233*^9}, {3.575046775423994*^9, 3.575046851474601*^9}, {
   3.5750480167236233`*^9, 3.5750480894829187`*^9}, {3.575048121501575*^9, 
   3.575048177377039*^9}, {3.5750483497762413`*^9, 3.575048360118473*^9}, {
   3.575048419869735*^9, 3.57504850768235*^9}, {3.575048595567359*^9, 
   3.5750486008567057`*^9}, {3.5750487766898527`*^9, 
   3.5750487784630613`*^9}, {3.575050707431229*^9, 3.575050707544672*^9}, 
   3.5750606260595407`*^9, {3.5750641759822683`*^9, 3.575064178254396*^9}, 
   3.5750649299763527`*^9, 3.575105473066049*^9, 3.575107126836224*^9, {
   3.5759723520395308`*^9, 3.57597235221631*^9}, {3.5931858840499973`*^9, 
   3.5931858914149*^9}, {3.593185956279048*^9, 3.593186102430492*^9}, 
   3.5931862066499157`*^9, {3.5931862626265287`*^9, 3.593186264567739*^9}, {
   3.593186306821208*^9, 3.5931863325410967`*^9}, {3.593186451784833*^9, 
   3.5931864685737553`*^9}, {3.593186560611465*^9, 3.593186638367209*^9}, 
   3.593186784078413*^9, {3.5931879400813313`*^9, 3.5931879569618683`*^9}, {
   3.593190872952272*^9, 3.593190873126588*^9}, {3.59324969303555*^9, 
   3.593249697892516*^9}, {3.593249965751988*^9, 3.593249972704137*^9}, {
   3.5940519354718113`*^9, 3.594051938470107*^9}, {3.59405209456308*^9, 
   3.5940521117387123`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Energy consumption vs. flowrate", "Subsection",
 CellChangeTimes->{{3.575061686037902*^9, 3.575061688982065*^9}, {
  3.575065135971407*^9, 3.575065137161293*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"RequiredP", "[", 
    RowBox[{
     RowBox[{"Q0_", "?", "NumberQ"}], ",", 
     RowBox[{"recov_", "?", "NumberQ"}], ",", 
     RowBox[{"c0_", "?", "NumberQ"}], ",", 
     RowBox[{"Lp_", "?", "NumberQ"}], ",", 
     RowBox[{"Lc_", "?", "NumberQ"}]}], "]"}], ":=", 
   RowBox[{"x", "/.", 
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Recovery", "[", 
         RowBox[{"x", ",", "Q0", ",", "c0", ",", "Lp", ",", "Lc"}], "]"}], 
        "\[Equal]", "recov"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"1.", "*", 
         SuperscriptBox["10", "5"]}]}], "}"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"energycons3", "[", 
    RowBox[{
     RowBox[{"Q0_", "?", "NumberQ"}], ",", 
     RowBox[{"recov_", "?", "NumberQ"}], ",", 
     RowBox[{"c0_", "?", "NumberQ"}], ",", 
     RowBox[{"Lp_", "?", "NumberQ"}], ",", 
     RowBox[{"Lc_", "?", "NumberQ"}], ",", 
     RowBox[{"\[Xi]_", "?", "NumberQ"}]}], "]"}], ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"thisP", "=", 
      RowBox[{"ToSI", "[", 
       RowBox[{"RequiredP", "[", 
        RowBox[{"Q0", ",", "recov", ",", "c0", ",", "Lp", ",", "Lc"}], "]"}], 
       "]"}]}], ";", 
     RowBox[{
      FractionBox["1", "3600000"], 
      FractionBox["1", "\[Eta]"], 
      FractionBox["1", "recov"], 
      RowBox[{"(", 
       RowBox[{"thisP", "-", 
        RowBox[{"\[Xi]", 
         RowBox[{"(", 
          RowBox[{"1", "-", "recov"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"thisP", "-", 
           RowBox[{"PLost", "[", 
            RowBox[{"thisP", ",", "Q0", ",", "c0", ",", "Lp", ",", "Lc"}], 
            "]"}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"energycons3", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Qout", "/", "86400"}], "/", "RRdefaultSW"}], ",", 
         "RRdefaultSW", ",", "c0DefaultSW", ",", 
         RowBox[{"1.", "lmhbar"}], ",", "LcDefaultSW", ",", "\[Xi]SW"}], 
        "]"}], ",", 
       RowBox[{"energycons3", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Qout", "/", "86400"}], "/", "RRdefaultSW"}], ",", 
         "RRdefaultSW", ",", "c0DefaultSW", ",", 
         RowBox[{"3", "lmhbar"}], ",", "LcDefaultSW", ",", "\[Xi]SW"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"energycons3", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Qout", "/", "86400"}], "/", "RRdefaultBW"}], ",", 
         "RRdefaultBW", ",", "c0DefaultBW", ",", 
         RowBox[{"1.5", "lmhbar"}], ",", "LcDefaultBW", ",", "\[Xi]BW"}], 
        "]"}], ",", 
       RowBox[{"energycons3", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Qout", "/", "86400"}], "/", "RRdefaultBW"}], ",", 
         "RRdefaultBW", ",", "c0DefaultBW", ",", 
         RowBox[{"4.5", "lmhbar"}], ",", "LcDefaultBW", ",", "\[Xi]BW"}], 
        "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"energycons3", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Qout", "/", "86400"}], "/", "RRdefaultOGW"}], ",", 
         "RRdefaultOGW", ",", "c0DefaultOGW", ",", 
         RowBox[{"1.", "lmhbar"}], ",", "LcDefaultOGW", ",", "\[Xi]OGW"}], 
        "]"}], ",", 
       RowBox[{"energycons3", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Qout", "/", "86400"}], "/", "RRdefaultOGW"}], ",", 
         "RRdefaultOGW", ",", "c0DefaultOGW", ",", 
         RowBox[{"3", "lmhbar"}], ",", "LcDefaultOGW", ",", "\[Xi]OGW"}], 
        "]"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"Qout", ",", "10", ",", "500"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Directive", "[", 
       RowBox[{"Thick", ",", "Purple"}], "]"}], ",", 
      RowBox[{"Directive", "[", 
       RowBox[{"Dotted", ",", "Thick", ",", "Purple"}], "]"}], ",", 
      RowBox[{"Directive", "[", 
       RowBox[{"Thick", ",", "Orange"}], "]"}], ",", 
      RowBox[{"Directive", "[", 
       RowBox[{"Thick", ",", "Dotted", ",", "Orange"}], "]"}], ",", 
      RowBox[{"Directive", "[", 
       RowBox[{"Thick", ",", "Black"}], "]"}], ",", 
      RowBox[{"Directive", "[", 
       RowBox[{"Dotted", ",", "Thick", ",", "Black"}], "]"}]}], "}"}]}], ",", 
   
   RowBox[{"AxesLabel", "\[Rule]", "Automatic"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "10"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Permeate per vessel (\!\(\*SuperscriptBox[\(m\), \(3\)]\)/d)\>\"", 
      ",", "\"\<Energy consumption (kWh/m3)\>\""}], "}"}]}], ",", 
   RowBox[{"Filling", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "\[Rule]", 
       RowBox[{"{", "2", "}"}]}], ",", 
      RowBox[{"3", "\[Rule]", 
       RowBox[{"{", "4", "}"}]}], ",", 
      RowBox[{"5", "\[Rule]", 
       RowBox[{"{", "6", "}"}]}]}], "}"}]}], ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<TFC\>\"", ",", "\"\<UPM\>\""}], "}"}]}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"SwatchLegend", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Purple", ",", "Orange", ",", "Black"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Seawater\>\"", ",", "\"\<Brackish water\>\"", ",", 
     "\"\<Flowback water\>\""}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.575061727144053*^9, 3.575061822788957*^9}, {
   3.575061945220072*^9, 3.575062001746806*^9}, {3.575062113806039*^9, 
   3.575062121259183*^9}, 3.575062337736868*^9, {3.5750624627437*^9, 
   3.575062565633716*^9}, {3.575062623505262*^9, 3.57506262657063*^9}, {
   3.575063338699306*^9, 3.575063488251691*^9}, 3.575063799043908*^9, 
   3.575064085732998*^9, {3.5750643899978037`*^9, 3.5750643983195467`*^9}, {
   3.5750644765820312`*^9, 3.575064521009302*^9}, {3.5750649578674793`*^9, 
   3.575064961496675*^9}, {3.5750651448177567`*^9, 3.575065217565215*^9}, {
   3.575065545338687*^9, 3.575065581065827*^9}, 3.5750658887772903`*^9, {
   3.575065978477337*^9, 3.575066062040123*^9}, {3.575066434452927*^9, 
   3.575066503248865*^9}, {3.575066556178141*^9, 3.575066663333448*^9}, {
   3.575066707470871*^9, 3.575066708248253*^9}, 3.575102860201355*^9, {
   3.575102893913086*^9, 3.57510289412764*^9}, {3.575105500063014*^9, 
   3.575105501271537*^9}, {3.575588990925914*^9, 3.57558899249485*^9}, {
   3.5756174595373373`*^9, 3.575617460260024*^9}, {3.575621372084836*^9, 
   3.575621391794203*^9}, {3.575971284780068*^9, 3.5759713181466722`*^9}, {
   3.575971392447811*^9, 3.5759714019439087`*^9}, 3.575971712850253*^9, {
   3.575971777653759*^9, 3.575971792887948*^9}, {3.588419764160569*^9, 
   3.5884197699219027`*^9}, {3.593186936397464*^9, 3.593186941344966*^9}, {
   3.593250809820682*^9, 3.593250811953884*^9}, {3.593250860203704*^9, 
   3.593250861641227*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cost implications", "Section",
 CellChangeTimes->{{3.594052059031849*^9, 3.594052060340396*^9}}],

Cell[CellGroupData[{

Cell["SWRO", "Subsubsection",
 CellChangeTimes->{{3.593368176274848*^9, 3.593368176576789*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{"\"\<Original energy cost:\>\"", "\[IndentingNewLine]", 
 RowBox[{"a", "=", 
  RowBox[{
   RowBox[{"CostofElectricity", "*", 
    RowBox[{"energycons3", "[", 
     RowBox[{
      RowBox[{"Qin", "[", 
       RowBox[{"newcap", ",", "Q0DefaultSW"}], "]"}], ",", "RRdefaultSW", ",",
       "c0DefaultSW", ",", 
      RowBox[{"1.", "lmhbar"}], ",", "LcDefaultSW", ",", "\[Xi]SW"}], "]"}]}],
    "/.", 
   RowBox[{
   "newcap", "\[Rule]", 
    "AmmortizedCapitalPerM3"}]}]}], "\[IndentingNewLine]", "\"\<Lower energy \
cost (fixed capital cost):\>\"", "\[IndentingNewLine]", 
 RowBox[{"b", "=", 
  RowBox[{
   RowBox[{"CostofElectricity", "*", 
    RowBox[{"energycons3", "[", 
     RowBox[{
      RowBox[{"Qin", "[", 
       RowBox[{"newcap", ",", "Q0DefaultSW"}], "]"}], ",", "RRdefaultSW", ",",
       "c0DefaultSW", ",", 
      RowBox[{"3.", "lmhbar"}], ",", "LcDefaultSW", ",", "\[Xi]SW"}], "]"}]}],
    "/.", 
   RowBox[{
   "newcap", "\[Rule]", 
    "AmmortizedCapitalPerM3"}]}]}], "\[IndentingNewLine]", "\"\<Same energy \
cost (at 0.182 $/\!\(\*SuperscriptBox[\(m\), \(3\)]\) for capital \
costs):\>\"", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c", "=", 
   RowBox[{
    RowBox[{"CostofElectricity", "*", 
     RowBox[{"energycons3", "[", 
      RowBox[{
       RowBox[{"Qin", "[", 
        RowBox[{"newcap", ",", "Q0DefaultSW"}], "]"}], ",", "RRdefaultSW", 
       ",", "c0DefaultSW", ",", 
       RowBox[{"3.", "lmhbar"}], ",", "LcDefaultSW", ",", "\[Xi]SW"}], 
      "]"}]}], "/.", 
    RowBox[{"newcap", "\[Rule]", ".182"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Totalcost", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"AmmortizedCapitalPerM3", "+", "a"}], ")"}], "/", 
    RowBox[{"(", "0.81", ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", "\"\<Energy savings ($/m3):\>\"", "\
\[IndentingNewLine]", 
 RowBox[{"(", 
  RowBox[{"b", "-", "a"}], ")"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"b", "-", "a"}], ")"}], "/", "Totalcost"}], "*", "100", 
  "\"\<%\>\""}], "\[IndentingNewLine]", "\"\<Capital cost savings $/m3:\>\"", \
"\[IndentingNewLine]", 
 RowBox[{"(", 
  RowBox[{".182", "-", "AmmortizedCapitalPerM3"}], 
  ")"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{".182", "-", "AmmortizedCapitalPerM3"}], ")"}], "/", 
   "Totalcost"}], "*", "100", "\"\<%\>\""}]}], "Input",
 CellChangeTimes->{{3.593367949792171*^9, 3.593368124830203*^9}, {
   3.5933681726250963`*^9, 3.593368173799527*^9}, {3.593558984392086*^9, 
   3.593558991462689*^9}, {3.593559204244914*^9, 3.593559225431665*^9}, {
   3.593559447702722*^9, 3.593559474589052*^9}, {3.5935595259515657`*^9, 
   3.593559567840149*^9}, 3.594474439357006*^9}],

Cell[BoxData["\<\"Original energy cost:\"\>"], "Output",
 CellChangeTimes->{{3.5933679544575872`*^9, 3.5933680052265368`*^9}, 
   3.593368073516663*^9, 3.593368125430518*^9, 3.593558992919557*^9, 
   3.593559225874123*^9, 3.593559474990448*^9, {3.59355955015205*^9, 
   3.593559572802697*^9}}],

Cell[BoxData["0.27381133991713713`"], "Output",
 CellChangeTimes->{{3.5933679544575872`*^9, 3.5933680052265368`*^9}, 
   3.593368073516663*^9, 3.593368125430518*^9, 3.593558992919557*^9, 
   3.593559225874123*^9, 3.593559474990448*^9, {3.59355955015205*^9, 
   3.593559573645651*^9}}],

Cell[BoxData["\<\"Lower energy cost (fixed capital cost):\"\>"], "Output",
 CellChangeTimes->{{3.5933679544575872`*^9, 3.5933680052265368`*^9}, 
   3.593368073516663*^9, 3.593368125430518*^9, 3.593558992919557*^9, 
   3.593559225874123*^9, 3.593559474990448*^9, {3.59355955015205*^9, 
   3.593559573648192*^9}}],

Cell[BoxData["0.2482064014378941`"], "Output",
 CellChangeTimes->{{3.5933679544575872`*^9, 3.5933680052265368`*^9}, 
   3.593368073516663*^9, 3.593368125430518*^9, 3.593558992919557*^9, 
   3.593559225874123*^9, 3.593559474990448*^9, {3.59355955015205*^9, 
   3.5935595748673897`*^9}}],

Cell[BoxData["\<\"Same energy cost (at 0.27 \
$/\\!\\(\\*SuperscriptBox[\\(m\\), \\(3\\)]\\) for capital costs):\"\>"], \
"Output",
 CellChangeTimes->{{3.5933679544575872`*^9, 3.5933680052265368`*^9}, 
   3.593368073516663*^9, 3.593368125430518*^9, 3.593558992919557*^9, 
   3.593559225874123*^9, 3.593559474990448*^9, {3.59355955015205*^9, 
   3.5935595748701*^9}}],

Cell[BoxData["0.27265655260332794`"], "Output",
 CellChangeTimes->{{3.5933679544575872`*^9, 3.5933680052265368`*^9}, 
   3.593368073516663*^9, 3.593368125430518*^9, 3.593558992919557*^9, 
   3.593559225874123*^9, 3.593559474990448*^9, {3.59355955015205*^9, 
   3.593559575906158*^9}}],

Cell[BoxData["\<\"Energy savings ($/m3):\"\>"], "Output",
 CellChangeTimes->{{3.5933679544575872`*^9, 3.5933680052265368`*^9}, 
   3.593368073516663*^9, 3.593368125430518*^9, 3.593558992919557*^9, 
   3.593559225874123*^9, 3.593559474990448*^9, {3.59355955015205*^9, 
   3.593559575909322*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.025604938479243028`"}]], "Output",
 CellChangeTimes->{{3.5933679544575872`*^9, 3.5933680052265368`*^9}, 
   3.593368073516663*^9, 3.593368125430518*^9, 3.593558992919557*^9, 
   3.593559225874123*^9, 3.593559474990448*^9, {3.59355955015205*^9, 
   3.593559575912299*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "3.614428423666544`"}], " ", "\<\"%\"\>"}]], "Output",
 CellChangeTimes->{{3.5933679544575872`*^9, 3.5933680052265368`*^9}, 
   3.593368073516663*^9, 3.593368125430518*^9, 3.593558992919557*^9, 
   3.593559225874123*^9, 3.593559474990448*^9, {3.59355955015205*^9, 
   3.59355957591518*^9}}],

Cell[BoxData["\<\"Capital cost savings $/m3:\"\>"], "Output",
 CellChangeTimes->{{3.5933679544575872`*^9, 3.5933680052265368`*^9}, 
   3.593368073516663*^9, 3.593368125430518*^9, 3.593558992919557*^9, 
   3.593559225874123*^9, 3.593559474990448*^9, {3.59355955015205*^9, 
   3.593559575917674*^9}}],

Cell[BoxData[
 RowBox[{"-", "0.02699999999999997`"}]], "Output",
 CellChangeTimes->{{3.5933679544575872`*^9, 3.5933680052265368`*^9}, 
   3.593368073516663*^9, 3.593368125430518*^9, 3.593558992919557*^9, 
   3.593559225874123*^9, 3.593559474990448*^9, {3.59355955015205*^9, 
   3.5935595759199343`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "3.811357231657041`"}], " ", "\<\"%\"\>"}]], "Output",
 CellChangeTimes->{{3.5933679544575872`*^9, 3.5933680052265368`*^9}, 
   3.593368073516663*^9, 3.593368125430518*^9, 3.593558992919557*^9, 
   3.593559225874123*^9, 3.593559474990448*^9, {3.59355955015205*^9, 
   3.5935595759219913`*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["BWRO", "Subsubsection",
 CellChangeTimes->{{3.593368182042068*^9, 3.593368182761549*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{"\"\<Original energy cost:\>\"", "\[IndentingNewLine]", 
 RowBox[{"a", "=", 
  RowBox[{
   RowBox[{"CostofElectricity", "*", 
    RowBox[{"energycons3", "[", 
     RowBox[{
      RowBox[{"Qin", "[", 
       RowBox[{"newcap", ",", "Q0DefaultBW"}], "]"}], ",", "RRdefaultBW", ",",
       "c0DefaultBW", ",", 
      RowBox[{"1.5", "lmhbar"}], ",", "LcDefaultBW", ",", "\[Xi]BW"}], 
     "]"}]}], "/.", 
   RowBox[{
   "newcap", "\[Rule]", 
    "AmmortizedCapitalPerM3"}]}]}], "\[IndentingNewLine]", "\"\<Lower energy \
cost (fixed capital cost):\>\"", "\[IndentingNewLine]", 
 RowBox[{"b", "=", 
  RowBox[{
   RowBox[{"CostofElectricity", "*", 
    RowBox[{"energycons3", "[", 
     RowBox[{
      RowBox[{"Qin", "[", 
       RowBox[{"newcap", ",", "Q0DefaultBW"}], "]"}], ",", "RRdefaultBW", ",",
       "c0DefaultBW", ",", 
      RowBox[{"4.5", "lmhbar"}], ",", "LcDefaultBW", ",", "\[Xi]BW"}], 
     "]"}]}], "/.", 
   RowBox[{
   "newcap", "\[Rule]", 
    "AmmortizedCapitalPerM3"}]}]}], "\[IndentingNewLine]", "\"\<Same energy \
cost (at 0.175 $/\!\(\*SuperscriptBox[\(m\), \(3\)]\) for capital \
costs):\>\"", "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c", "=", 
   RowBox[{
    RowBox[{"CostofElectricity", "*", 
     RowBox[{"energycons3", "[", 
      RowBox[{
       RowBox[{"Qin", "[", 
        RowBox[{"newcap", ",", "Q0DefaultBW"}], "]"}], ",", "RRdefaultBW", 
       ",", "c0DefaultBW", ",", 
       RowBox[{"4.5", "lmhbar"}], ",", "LcDefaultBW", ",", "\[Xi]BW"}], 
      "]"}]}], "/.", 
    RowBox[{"newcap", "\[Rule]", ".175"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Totalcost", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"AmmortizedCapitalPerM3", "+", "a"}], ")"}], "/", 
    RowBox[{"(", "0.81", ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", "\"\<Energy savings ($/m3):\>\"", "\
\[IndentingNewLine]", 
 RowBox[{"(", 
  RowBox[{"b", "-", "a"}], ")"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"b", "-", "a"}], ")"}], "/", "Totalcost"}], "*", "100", 
  "\"\<%\>\""}], "\[IndentingNewLine]", "\"\<Capital cost savings \
($/m3):\>\"", "\[IndentingNewLine]", 
 RowBox[{"(", 
  RowBox[{".175", "-", "AmmortizedCapitalPerM3"}], 
  ")"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{".175", "-", "AmmortizedCapitalPerM3"}], ")"}], "/", 
   "Totalcost"}], "*", "100", "\"\<%\>\""}]}], "Input",
 CellChangeTimes->{{3.593368204929977*^9, 3.5933683091974297`*^9}, {
   3.593558924187594*^9, 3.593558954953847*^9}, {3.5935590613023453`*^9, 
   3.593559127338922*^9}, {3.5935596389806356`*^9, 3.5935596480417013`*^9}, 
   3.594474453275014*^9}],

Cell[BoxData["\<\"Original energy cost:\"\>"], "Output",
 CellChangeTimes->{{3.593368240163003*^9, 3.593368310722139*^9}, 
   3.593558865791028*^9, 3.5935589004270687`*^9, 3.593558955584631*^9, {
   3.593559117660048*^9, 3.593559128029213*^9}, 3.5935596484839277`*^9}],

Cell[BoxData["0.06887561080745172`"], "Output",
 CellChangeTimes->{{3.593368240163003*^9, 3.593368310722139*^9}, 
   3.593558865791028*^9, 3.5935589004270687`*^9, 3.593558955584631*^9, {
   3.593559117660048*^9, 3.593559128029213*^9}, 3.593559649203272*^9}],

Cell[BoxData["\<\"Lower energy cost (fixed capital cost):\"\>"], "Output",
 CellChangeTimes->{{3.593368240163003*^9, 3.593368310722139*^9}, 
   3.593558865791028*^9, 3.5935589004270687`*^9, 3.593558955584631*^9, {
   3.593559117660048*^9, 3.593559128029213*^9}, 3.5935596492056103`*^9}],

Cell[BoxData["0.03666291170170409`"], "Output",
 CellChangeTimes->{{3.593368240163003*^9, 3.593368310722139*^9}, 
   3.593558865791028*^9, 3.5935589004270687`*^9, 3.593558955584631*^9, {
   3.593559117660048*^9, 3.593559128029213*^9}, 3.5935596501673613`*^9}],

Cell[BoxData["\<\"Same energy cost (at 0.27 \
$/\\!\\(\\*SuperscriptBox[\\(m\\), \\(3\\)]\\) for capital costs):\"\>"], \
"Output",
 CellChangeTimes->{{3.593368240163003*^9, 3.593368310722139*^9}, 
   3.593558865791028*^9, 3.5935589004270687`*^9, 3.593558955584631*^9, {
   3.593559117660048*^9, 3.593559128029213*^9}, 3.593559650169821*^9}],

Cell[BoxData["0.06890326299414325`"], "Output",
 CellChangeTimes->{{3.593368240163003*^9, 3.593368310722139*^9}, 
   3.593558865791028*^9, 3.5935589004270687`*^9, 3.593558955584631*^9, {
   3.593559117660048*^9, 3.593559128029213*^9}, 3.593559650811078*^9}],

Cell[BoxData["\<\"Energy savings ($/m3):\"\>"], "Output",
 CellChangeTimes->{{3.593368240163003*^9, 3.593368310722139*^9}, 
   3.593558865791028*^9, 3.5935589004270687`*^9, 3.593558955584631*^9, {
   3.593559117660048*^9, 3.593559128029213*^9}, 3.5935596508133993`*^9}],

Cell[BoxData[
 RowBox[{"-", "0.03221269910574763`"}]], "Output",
 CellChangeTimes->{{3.593368240163003*^9, 3.593368310722139*^9}, 
   3.593558865791028*^9, 3.5935589004270687`*^9, 3.593558955584631*^9, {
   3.593559117660048*^9, 3.593559128029213*^9}, 3.5935596508154287`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "7.073464742909073`"}], " ", "\<\"%\"\>"}]], "Output",
 CellChangeTimes->{{3.593368240163003*^9, 3.593368310722139*^9}, 
   3.593558865791028*^9, 3.5935589004270687`*^9, 3.593558955584631*^9, {
   3.593559117660048*^9, 3.593559128029213*^9}, 3.593559650817457*^9}],

Cell[BoxData["\<\"Capital cost savings ($/m3):\"\>"], "Output",
 CellChangeTimes->{{3.593368240163003*^9, 3.593368310722139*^9}, 
   3.593558865791028*^9, 3.5935589004270687`*^9, 3.593558955584631*^9, {
   3.593559117660048*^9, 3.593559128029213*^9}, 3.5935596508192463`*^9}],

Cell[BoxData[
 RowBox[{"-", "0.03799999999999998`"}]], "Output",
 CellChangeTimes->{{3.593368240163003*^9, 3.593368310722139*^9}, 
   3.593558865791028*^9, 3.5935589004270687`*^9, 3.593558955584631*^9, {
   3.593559117660048*^9, 3.593559128029213*^9}, 3.593559650821312*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "8.344276254161665`"}], " ", "\<\"%\"\>"}]], "Output",
 CellChangeTimes->{{3.593368240163003*^9, 3.593368310722139*^9}, 
   3.593558865791028*^9, 3.5935589004270687`*^9, 3.593558955584631*^9, {
   3.593559117660048*^9, 3.593559128029213*^9}, 3.593559650823349*^9}]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{GraphicsComplexBox[CompressedData["
1:eJw91Wk8llkfwHGUke0WaSTKEMp6I7INf5FUTAulrJUlSiRElkmbeUhSDcmQ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    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
      {Hue[0.67, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{55, 86, 71, 101, 56, 87, 72, 102, 57, 88, 73, 103, 58, 
         89, 74, 104, 59, 90, 75, 105, 60, 91, 76, 106, 61, 92, 77, 107, 62, 
         93, 78, 108, 63, 94, 79, 109, 64, 95, 80, 110, 65, 96, 81, 66, 97, 
         82, 67, 98, 83, 68, 99, 84, 69, 100, 85, 111, 70, 16, 54, 31, 46, 15,
          30, 45, 14, 29, 44, 13, 28, 43, 12, 27, 42, 11, 26, 41, 10, 25, 40, 
         9, 24, 39, 8, 53, 23, 38, 7, 52, 22, 37, 6, 51, 21, 36, 5, 50, 20, 
         35, 4, 49, 19, 34, 3, 48, 18, 33, 2, 47, 17, 32, 
         1}}]]}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
      {Hue[0.1421359549995791, 0.6, 0.6], Opacity[0.2], EdgeForm[None], 
       GraphicsGroupBox[
        PolygonBox[{{153, 180, 169, 191, 154, 181, 170, 192, 155, 182, 171, 
         193, 156, 183, 172, 194, 157, 184, 173, 195, 158, 185, 174, 159, 186,
          175, 160, 187, 176, 161, 188, 177, 162, 189, 178, 163, 164, 165, 
         166, 167, 190, 179, 196, 168, 127, 152, 137, 147, 126, 125, 124, 123,
          122, 121, 136, 146, 120, 135, 145, 119, 134, 144, 118, 133, 143, 
         117, 132, 142, 116, 151, 131, 141, 115, 150, 130, 140, 114, 149, 129,
          139, 113, 148, 128, 138, 112}}]]}, {}, {}}, {{}, {}, {}, 
      {RGBColor[0.5, 0, 0.5], Thickness[Large], 
       LineBox[{1, 32, 17, 47, 2, 33, 18, 48, 3, 34, 19, 49, 4, 35, 20, 50, 5,
         36, 21, 51, 6, 37, 22, 52, 7, 38, 23, 53, 8, 39, 24, 9, 40, 25, 10, 
        41, 26, 11, 42, 27, 12, 43, 28, 13, 44, 29, 14, 45, 30, 15, 46, 31, 
        54, 16}]}, 
      {RGBColor[0.5, 0, 0.5], Thickness[Large], Dashing[{0, Small}], 
       LineBox[{55, 86, 71, 101, 56, 87, 72, 102, 57, 88, 73, 103, 58, 89, 74,
         104, 59, 90, 75, 105, 60, 91, 76, 106, 61, 92, 77, 107, 62, 93, 78, 
        108, 63, 94, 79, 109, 64, 95, 80, 110, 65, 96, 81, 66, 97, 82, 67, 98,
         83, 68, 99, 84, 69, 100, 85, 111, 70}]}, 
      {RGBColor[1, 0.5, 0], Thickness[Large], 
       LineBox[{112, 138, 128, 148, 113, 139, 129, 149, 114, 140, 130, 150, 
        115, 141, 131, 151, 116, 142, 132, 117, 143, 133, 118, 144, 134, 119, 
        145, 135, 120, 146, 136, 121, 122, 123, 124, 125, 126, 147, 137, 152, 
        127}]}, 
      {RGBColor[1, 0.5, 0], Thickness[Large], Dashing[{0, Small}], 
       LineBox[{153, 180, 169, 191, 154, 181, 170, 192, 155, 182, 171, 193, 
        156, 183, 172, 194, 157, 184, 173, 195, 158, 185, 174, 159, 186, 175, 
        160, 187, 176, 161, 188, 177, 162, 189, 178, 163, 164, 165, 166, 167, 
        190, 179, 196, 168}]}}}], 
   {Thickness[Large], StrokeForm[Hue[0.67, 0.6, 0.6]], EdgeForm[{Hue[
    0.6699931334401464, 0.6, 0.6], Opacity[1.], AbsoluteThickness[2]}], 
    EdgeForm[None], FaceForm[None], 
    ArrowBox[{{0.29992150047938637`, 0.08463169334914333}, {
     0.26395113629554173`, 0.08463169334914333}}]}, 
   {Thickness[Large], StrokeForm[Hue[0.67, 0.6, 0.6]], EdgeForm[{Hue[
    0.6699931334401464, 0.6, 0.6], Opacity[1.], AbsoluteThickness[2]}], 
    EdgeForm[None], FaceForm[None], 
    ArrowBox[{{0.2994705162208245, 0.2752096791604517}, {0.2755053381947567, 
     0.2752096791604517}}]}, 
   {Thickness[Large], StrokeForm[Hue[0.67, 0.6, 0.6]], EdgeForm[{Hue[
    0.6699931334401464, 0.6, 0.6], Opacity[1.], AbsoluteThickness[2]}], 
    EdgeForm[None], FaceForm[None], 
    ArrowBox[{{0.299621883988495, 0.08227969153601888}, {0.2996218839884948, 
     0.041312597455075206`}}]}, 
   {Thickness[Large], Arrowheads[0.02654605561975539], StrokeForm[Hue[
    0.67, 0.6, 0.6]], EdgeForm[{Hue[0.6699931334401464, 0.6, 0.6], Opacity[
    1.], AbsoluteThickness[2]}], EdgeForm[None], FaceForm[None], 
    ArrowBox[{{0.2993763405903579, 0.2744240145840715}, {0.2993763405903578, 
     0.2550517710939725}}]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["newcap", TraditionalForm], 
    FormBox["\"\"", TraditionalForm]},
  AxesOrigin->{0.26, 0},
  BaseStyle->{FontFamily -> $CellContext`Helvetica, FontSize -> 12},
  Frame->{True, True, False, False},
  FrameLabel->{{
     FormBox[
     "\"Energy cost ($/\\!\\(\\*SuperscriptBox[\\(m\\), \\(3\\)]\\))\"", 
      TraditionalForm], None}, {
     FormBox[
     "\"Capital cost, levelized ($/\\!\\(\\*SuperscriptBox[\\(m\\), \
\\(3\\)]\\))\"", TraditionalForm], None}},
  ImagePadding->{{46., 1.1}, {43., 0.1}},
  Method->{"AxesInFront" -> True},
  PlotRange->{{0.258125, 0.351875}, {0., 0.45483677873491785`}},
  PlotRangeClipping->True,
  PlotRangePadding->Automatic]], "Input",
 CellChangeTimes->{{3.593365967330895*^9, 3.5933660917248173`*^9}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1141, 625},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 198, 5, 148, "Title"],
Cell[780, 29, 666, 9, 51, "Subtitle"],
Cell[CellGroupData[{
Cell[1471, 42, 108, 1, 35, "Subsubsection"],
Cell[1582, 45, 5406, 134, 199, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7025, 184, 243, 3, 80, "Section"],
Cell[CellGroupData[{
Cell[7293, 191, 149, 2, 44, "Subsection"],
Cell[7445, 195, 3143, 89, 206, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10625, 289, 188, 7, 44, "Subsection"],
Cell[10816, 298, 3040, 81, 227, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[13893, 384, 108, 1, 44, "Subsection"],
Cell[14004, 387, 1124, 32, 70, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15165, 424, 226, 6, 44, "Subsection"],
Cell[15394, 432, 2725, 71, 124, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18156, 508, 225, 7, 44, "Subsection"],
Cell[18384, 517, 9126, 238, 463, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27547, 760, 108, 1, 44, "Subsection"],
Cell[CellGroupData[{
Cell[27680, 765, 197, 3, 35, "Subsubsection"],
Cell[27880, 770, 627, 15, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[28544, 790, 200, 2, 35, "Subsubsection"],
Cell[28747, 794, 4605, 116, 333, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[33413, 917, 94, 1, 80, "Section"],
Cell[CellGroupData[{
Cell[33532, 922, 105, 1, 44, "Subsection"],
Cell[33640, 925, 4279, 103, 212, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37956, 1033, 104, 1, 44, "Subsection"],
Cell[38063, 1036, 5012, 123, 191, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43112, 1164, 168, 2, 44, "Subsection"],
Cell[43283, 1168, 7110, 177, 311, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[50442, 1351, 102, 1, 80, "Section"],
Cell[CellGroupData[{
Cell[50569, 1356, 95, 1, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[50689, 1361, 2749, 71, 286, "Input"],
Cell[53441, 1434, 293, 4, 28, "Output"],
Cell[53737, 1440, 284, 4, 28, "Output"],
Cell[54024, 1446, 311, 4, 28, "Output"],
Cell[54338, 1452, 285, 4, 28, "Output"],
Cell[54626, 1458, 366, 6, 32, "Output"],
Cell[54995, 1466, 284, 4, 28, "Output"],
Cell[55282, 1472, 294, 4, 28, "Output"],
Cell[55579, 1478, 302, 5, 28, "Output"],
Cell[55884, 1485, 329, 6, 28, "Output"],
Cell[56216, 1493, 298, 4, 28, "Output"],
Cell[56517, 1499, 303, 5, 28, "Output"],
Cell[56823, 1506, 332, 6, 28, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[57204, 1518, 95, 1, 35, "Subsubsection"],
Cell[CellGroupData[{
Cell[57324, 1523, 2666, 70, 303, "Input"],
Cell[59993, 1595, 268, 3, 28, "Output"],
Cell[60264, 1600, 257, 3, 28, "Output"],
Cell[60524, 1605, 286, 3, 28, "Output"],
Cell[60813, 1610, 259, 3, 28, "Output"],
Cell[61075, 1615, 341, 5, 32, "Output"],
Cell[61419, 1622, 257, 3, 28, "Output"],
Cell[61679, 1627, 269, 3, 28, "Output"],
Cell[61951, 1632, 276, 4, 28, "Output"],
Cell[62230, 1638, 303, 5, 28, "Output"],
Cell[62536, 1645, 275, 3, 28, "Output"],
Cell[62814, 1650, 274, 4, 28, "Output"],
Cell[63091, 1656, 303, 5, 28, "Output"]
}, Open  ]],
Cell[63409, 1664, 7709, 131, 251, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
